@@ -7,7 +7,7 @@ import pytest
 from rest_email_auth import authentication
 
 
-@pytest.fixture(scope='session')
+@pytest.fixture(scope="session")
 def base_auth_backend():
     """
     Return an instance of the base authentication backend.
@@ -15,7 +15,7 @@ def base_auth_backend():
     return authentication.BaseBackend()
 
 
-@pytest.fixture(scope='session')
+@pytest.fixture(scope="session")
 def verified_email_auth_backend():
     """
     Return an instance of the authentication backend that only accepts
