@@ -7,6 +7,7 @@ class ExampleSerializer(serializers.Serializer):
     """
     Serializer for testing views.
     """
+
     foo = serializers.CharField()
 
     def save(self):
@@ -20,6 +21,7 @@ class ExampleView(generics.SerializerSaveView):
     """
     View that extends from the generic view we're testing.
     """
+
     serializer_class = ExampleSerializer
 
 
@@ -28,7 +30,7 @@ def test_post_invalid(api_rf):
     Sending an invalid POST request to the view should return the
     serializer's errors.
     """
-    request = api_rf.post('/', {})
+    request = api_rf.post("/", {})
     response = ExampleView.as_view()(request)
 
     assert response.status_code == status.HTTP_400_BAD_REQUEST
@@ -44,11 +46,9 @@ def test_post_valid(api_rf):
     Sending a valid POST request to the view should call the
     serializer's ``save`` method and return the serializer's data.
     """
-    data = {
-        'foo': 'bar',
-    }
+    data = {"foo": "bar"}
 
-    request = api_rf.post('/', data)
+    request = api_rf.post("/", data)
     response = ExampleView.as_view()(request)
 
     assert response.status_code == status.HTTP_200_OK
