@@ -12,11 +12,9 @@ def test_generate_token():
     getting a random string to create a random string.
     """
     with mock.patch(
-            'rest_email_auth.models.get_random_string',
-            autospec=True) as mock_random:
+        "rest_email_auth.models.get_random_string", autospec=True
+    ) as mock_random:
         models.generate_token()
 
     assert mock_random.call_count == 1
-    assert mock_random.call_args[1] == {
-        'length': 64,
-    }
+    assert mock_random.call_args[1] == {"length": 64}
