@@ -7,22 +7,20 @@ from rest_framework import status
 from rest_framework.reverse import reverse
 
 
-url = reverse('rest-email-auth:password-reset')
+url = reverse("rest-email-auth:password-reset")
 
 
 @mock.patch(
-    'rest_email_auth.views.serializers.PasswordResetSerializer.save',
-    autospec=True)
+    "rest_email_auth.views.serializers.PasswordResetSerializer.save",
+    autospec=True,
+)
 def test_request_reset(mock_save, api_client, password_reset_token_factory):
     """
     Sending a POST request with valid data to the view should reset the
     user's password.
     """
     token = password_reset_token_factory()
-    data = {
-        'key': token.key,
-        'password': 'new_passw0rd',
-    }
+    data = {"key": token.key, "password": "new_passw0rd"}
 
     response = api_client.post(url, data)
 
